from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int

Sixpack_V0_1_0 = CommandToolBuilder(tool="sixpack", base_command=["sixpack"], inputs=[ToolInput(tag="in_out_seq", input_type=Boolean(optional=True), prefix="-outseq", doc=InputDocumentation(doc="seqoutall  [<sequence>.<format>] ORF sequence output")), ToolInput(tag="in_table", input_type=Boolean(optional=True), prefix="-table", doc=InputDocumentation(doc="menu       [0] Genetics code used for the translation\n(Values: 0 (Standard); 1 (Standard (with\nalternative initiation codons)); 2\n(Vertebrate Mitochondrial); 3 (Yeast\nMitochondrial); 4 (Mold, Protozoan,\nCoelenterate Mitochondrial and\nMycoplasma/Spiroplasma); 5 (Invertebrate\nMitochondrial); 6 (Ciliate Macronuclear and\nDasycladacean); 9 (Echinoderm\nMitochondrial); 10 (Euplotid Nuclear); 11\n(Bacterial); 12 (Alternative Yeast Nuclear);\n13 (Ascidian Mitochondrial); 14 (Flatworm\nMitochondrial); 15 (Blepharisma\nMacronuclear); 16 (Chlorophycean\nMitochondrial); 21 (Trematode\nMitochondrial); 22 (Scenedesmus obliquus);\n23 (Thraustochytrium Mitochondrial))")), ToolInput(tag="in_or_fm_in_size", input_type=Boolean(optional=True), prefix="-orfminsize", doc=InputDocumentation(doc="integer    [1] Minimum protein size of Open Reading\nFrames (ORFs) to display in the\ntranslations. (Integer 1 or more)")), ToolInput(tag="in_uppercase", input_type=Boolean(optional=True), prefix="-uppercase", doc=InputDocumentation(doc="range      [If this is left blank, then the sequence\ncase is left alone.] Regions to put in\nuppercase.\nIf this is left blank, then the sequence\ncase is left alone.\nA set of regions is specified by a set of\npairs of positions.\nThe positions are integers.\nThey are separated by any non-digit,\nnon-alpha character.\nExamples of region specifications are:\n24-45, 56-78\n1:45, 67=99;765..888\n1,5,8,10,23,45,57,99")), ToolInput(tag="in_highlight", input_type=Boolean(optional=True), prefix="-highlight", doc=InputDocumentation(doc="range      [(full sequence)] Regions to colour if\nformatting for HTML.\nIf this is left blank, then the sequence is\nleft alone.\nA set of regions is specified by a set of\npairs of positions.\nThe positions are integers.\nThey are followed by any valid HTML font\ncolour.\nExamples of region specifications are:\n24-45 blue 56-78 orange\n1-100 green 120-156 red\nA file of ranges to colour (one range per\nline) can be specified as '@filename'.")), ToolInput(tag="in_width", input_type=Boolean(optional=True), prefix="-width", doc=InputDocumentation(doc="integer    [60] Number of nucleotides displayed on each\nline (Integer 1 or more)")), ToolInput(tag="in_length", input_type=Boolean(optional=True), prefix="-length", doc=InputDocumentation(doc="integer    [0] Line length of page (0 for indefinite)\n(Integer 0 or more)")), ToolInput(tag="in_margin", input_type=Boolean(optional=True), prefix="-margin", doc=InputDocumentation(doc="integer    [10] Margin around sequence for numbering.\n(Integer 0 or more)")), ToolInput(tag="in_offset", input_type=Boolean(optional=True), prefix="-offset", doc=InputDocumentation(doc="integer    [1] Number from which you want the DNA\nsequence to be numbered. (Any integer value)")), ToolInput(tag="in_html", input_type=Boolean(optional=True), prefix="-html", doc=InputDocumentation(doc="boolean    [N] Use HTML formatting")), ToolInput(tag="in_size_dot", input_type=Int(), position=0, doc=InputDocumentation(doc="-mstart             boolean    [N] Displays only ORFs starting with an M."))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Sixpack_V0_1_0().translate("wdl", allow_empty_container=True)

